@@ -10,6 +10,7 @@ from rest_framework.response import Response
 from django_large_image import tilesource, utilities
 from django_large_image.rest import params
 from django_large_image.rest.base import CACHE_TIMEOUT, LargeImageMixinBase
+from django_large_image.rest.renderers import image_data_renderers, image_renderers
 
 thumbnail_summary = 'Returns thumbnail of full image.'
 thumbnail_parameters = params.BASE + params.THUMBNAIL + params.STYLE
@@ -23,8 +24,18 @@ histogram_parameters = params.BASE + params.HISTOGRAM
 
 class DataMixin(LargeImageMixinBase):
     @method_decorator(cache_page(CACHE_TIMEOUT))
-    def thumbnail(self, request: Request, pk: int = None, format: str = None) -> HttpResponse:
-        encoding = tilesource.format_to_encoding(format)
+    @swagger_auto_schema(
+        method='GET',
+        operation_summary=thumbnail_summary,
+        manual_parameters=thumbnail_parameters,
+    )
+    @action(
+        detail=False,
+        url_path=r'data/thumbnail.(?P<fmt>png|jpg|jpeg)',
+        renderer_classes=image_renderers,
+    )
+    def thumbnail(self, request: Request, pk: int = None, fmt: str = 'png') -> HttpResponse:
+        encoding = tilesource.format_to_encoding(fmt)
         width = int(self.get_query_param(request, 'max_width', 256))
         height = int(self.get_query_param(request, 'max_height', 256))
         source = self.get_tile_source(request, pk, encoding=encoding)
@@ -33,23 +44,15 @@ class DataMixin(LargeImageMixinBase):
 
     @swagger_auto_schema(
         method='GET',
-        operation_summary=thumbnail_summary,
-        manual_parameters=thumbnail_parameters,
+        operation_summary=region_summary,
+        manual_parameters=region_parameters + params.STYLE,
     )
-    @action(detail=False, url_path='thumbnail.png')
-    def thumbnail_png(self, request: Request, pk: int = None) -> HttpResponse:
-        return self.thumbnail(request, pk, format='png')
-
-    @swagger_auto_schema(
-        method='GET',
-        operation_summary=thumbnail_summary,
-        manual_parameters=thumbnail_parameters,
+    @action(
+        detail=False,
+        url_path=r'data/region.(?P<fmt>png|jpg|jpeg|tif|tiff)',
+        renderer_classes=image_data_renderers,
     )
-    @action(detail=False, url_path='thumbnail.jpeg')
-    def thumbnail_jpeg(self, request: Request, pk: int = None) -> HttpResponse:
-        return self.thumbnail(request, pk, format='jpeg')
-
-    def region(self, request: Request, pk: int = None, format: str = None) -> HttpResponse:
+    def region(self, request: Request, pk: int = None, fmt: str = 'tiff') -> HttpResponse:
         """Return the region tile binary from world coordinates in given EPSG.
 
         Note
@@ -62,7 +65,7 @@ class DataMixin(LargeImageMixinBase):
         """
         source = self.get_tile_source(request, pk)
         units = self.get_query_param(request, 'units')
-        encoding = tilesource.format_to_encoding(format)
+        encoding = tilesource.format_to_encoding(fmt)
         left = float(self.get_query_param(request, 'left'))
         right = float(self.get_query_param(request, 'right'))
         top = float(self.get_query_param(request, 'top'))
@@ -83,39 +86,12 @@ class DataMixin(LargeImageMixinBase):
         tile_binary = open(path, 'rb')
         return HttpResponse(tile_binary, content_type=mime_type)
 
-    @swagger_auto_schema(
-        method='GET',
-        operation_summary=region_summary,
-        manual_parameters=region_parameters,
-    )
-    @action(detail=False, url_path=r'region.tif')
-    def region_tif(self, request: Request, pk: int = None) -> HttpResponse:
-        return self.region(request, pk, format='tif')
-
-    @swagger_auto_schema(
-        method='GET',
-        operation_summary=region_summary,
-        manual_parameters=region_parameters + params.STYLE,
-    )
-    @action(detail=False, url_path=r'region.png')
-    def region_png(self, request: Request, pk: int = None) -> HttpResponse:
-        return self.region(request, pk, format='png')
-
-    @swagger_auto_schema(
-        method='GET',
-        operation_summary=region_summary,
-        manual_parameters=region_parameters + params.STYLE,
-    )
-    @action(detail=False, url_path=r'region.jpeg')
-    def region_jpeg(self, request: Request, pk: int = None) -> HttpResponse:
-        return self.region(request, pk, format='jpeg')
-
     @swagger_auto_schema(
         method='GET',
         operation_summary=pixel_summary,
         manual_parameters=pixel_parameters,
     )
-    @action(detail=False)
+    @action(detail=False, url_path='data/pixel')
     def pixel(self, request: Request, pk: int = None) -> Response:
         left = int(self.get_query_param(request, 'left'))
         top = int(self.get_query_param(request, 'top'))
@@ -128,7 +104,7 @@ class DataMixin(LargeImageMixinBase):
         operation_summary=histogram_summary,
         manual_parameters=histogram_parameters,
     )
-    @action(detail=False)
+    @action(detail=False, url_path='data/histogram')
     def histogram(self, request: Request, pk: int = None) -> Response:
         only_min_max = not utilities.param_nully(self.get_query_param(request, 'onlyMinMax', False))
         density = not utilities.param_nully(self.get_query_param(request, 'density', False))
@@ -158,52 +134,33 @@ class DataDetailMixin(DataMixin):
         operation_summary=thumbnail_summary,
         manual_parameters=thumbnail_parameters,
     )
-    @action(detail=True, url_path='thumbnail.png')
-    def thumbnail_png(self, request: Request, pk: int = None) -> HttpResponse:
-        return super().thumbnail_png(request, pk)
-
-    @swagger_auto_schema(
-        method='GET',
-        operation_summary=thumbnail_summary,
-        manual_parameters=thumbnail_parameters,
+    @action(
+        detail=True,
+        url_path=r'data/thumbnail.(?P<fmt>png|jpg|jpeg)',
+        renderer_classes=image_renderers,
     )
-    @action(detail=True, url_path='thumbnail.jpeg')
-    def thumbnail_jpeg(self, request: Request, pk: int = None) -> HttpResponse:
-        return super().thumbnail_jpeg(request, pk)
-
-    @swagger_auto_schema(
-        method='GET',
-        operation_summary=region_summary,
-        manual_parameters=region_parameters,
-    )
-    @action(detail=True, url_path=r'region.tif')
-    def region_tif(self, request: Request, pk: int = None) -> HttpResponse:
-        return super().region_tif(request, pk)
+    def thumbnail(self, request: Request, pk: int = None, fmt: str = 'png') -> HttpResponse:
+        return super().thumbnail(request, pk, fmt)
 
     @swagger_auto_schema(
         method='GET',
         operation_summary=region_summary,
         manual_parameters=region_parameters + params.STYLE,
     )
-    @action(detail=True, url_path=r'region.png')
-    def region_png(self, request: Request, pk: int = None) -> HttpResponse:
-        return super().region_png(request, pk)
-
-    @swagger_auto_schema(
-        method='GET',
-        operation_summary=region_summary,
-        manual_parameters=region_parameters + params.STYLE,
+    @action(
+        detail=True,
+        url_path=r'data/region.(?P<fmt>png|jpg|jpeg|tif|tiff)',
+        renderer_classes=image_data_renderers,
     )
-    @action(detail=True, url_path=r'region.jpeg')
-    def region_jpeg(self, request: Request, pk: int = None) -> HttpResponse:
-        return super().region_jpeg(request, pk)
+    def region(self, request: Request, pk: int = None, fmt: str = 'tiff') -> HttpResponse:
+        return super().region(request, pk, fmt)
 
     @swagger_auto_schema(
         method='GET',
         operation_summary=pixel_summary,
         manual_parameters=pixel_parameters,
     )
-    @action(detail=True)
+    @action(detail=True, url_path='data/pixel')
     def pixel(self, request: Request, pk: int = None) -> Response:
         return super().pixel(request, pk)
 
@@ -212,6 +169,6 @@ class DataDetailMixin(DataMixin):
         operation_summary=histogram_summary,
         manual_parameters=histogram_parameters,
     )
-    @action(detail=True)
+    @action(detail=True, url_path='data/histogram')
     def histogram(self, request: Request, pk: int = None) -> Response:
         return super().histogram(request, pk)
